r196062 - Correct a user-visible static analyzer message typo
Alp Toker
alp at nuanti.com
Sun Dec 1 19:50:25 PST 2013
Author: alp
Date: Sun Dec 1 21:50:25 2013
New Revision: 196062
URL: http://llvm.org/viewvc/llvm-project?rev=196062&view=rev
Log:
Correct a user-visible static analyzer message typo
Modified:
cfe/trunk/lib/StaticAnalyzer/Checkers/MallocChecker.cpp
Modified: cfe/trunk/lib/StaticAnalyzer/Checkers/MallocChecker.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/StaticAnalyzer/Checkers/MallocChecker.cpp?rev=196062&r1=196061&r2=196062&view=diff
==============================================================================
--- cfe/trunk/lib/StaticAnalyzer/Checkers/MallocChecker.cpp (original)
+++ cfe/trunk/lib/StaticAnalyzer/Checkers/MallocChecker.cpp Sun Dec 1 21:50:25 2013
@@ -48,7 +48,7 @@ class RefState {
Allocated,
// Reference to released/freed memory.
Released,
// The responsibility for freeing resources has transfered from
// this reference. A relinquished symbol should not be freed.
Relinquished,
// We are no longer guaranteed to have observed all manipulations
@@ -2130,7 +2130,7 @@ MallocChecker::MallocBugVisitor::VisitNo
StackHint = new StackHintGeneratorForSymbol(Sym,
"Returning; memory was released");
} else if (isRelinquished(RS, RSPrev, S)) {
- Msg = "Memory ownership is transfered";
+ Msg = "Memory ownership is transferred";
StackHint = new StackHintGeneratorForSymbol(Sym, "");
} else if (isReallocFailedCheck(RS, RSPrev, S)) {
Mode = ReallocationFailed;
@@ -48,7 +48,7 @@ class RefState {
// Reference to released/freed memory.
Released,
- // The responsibility for freeing resources has transfered from
+ // The responsibility for freeing resources has transferred from
// this reference. A relinquished symbol should not be freed.
Relinquished,
More information about the cfe-commits
mailing list